@@ -308,7 +308,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
 
         final List<String> dynamicColumnIdentifiers = new ArrayList<String>();
         for (final String paramName : request.keySet()) {
-            if (!KNOWN_PARAMS.contains(paramName) && paramName.contains(".")) {
+            if (!KNOWN_PARAMS.contains(paramName) && paramName.indexOf('.') >= 0) {
                 dynamicColumnIdentifiers.add(paramName);
             }
         }
